'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var react = require('react');
var reactScroll = require('react-scroll');
var debounce = _interopDefault(require('lodash.debounce'));

function useScrollSpy() {
    var _a = react.useState(), current = _a[0], setCurrent = _a[1];
    react.useEffect(function () {
        // Watch for link click/transition events
        reactScroll.Events.scrollEvent.register('begin', function (to) {
            setCurrent(to);
        });
        reactScroll.Events.scrollEvent.register('end', function (to) {
            setCurrent(to);
        });
        // Watch for scroll events
        var scrollHandler = debounce(function () {
            setCurrent(reactScroll.scroller.getActiveLink());
        }, 250);
        window.addEventListener('scroll', scrollHandler);
        return function () {
            reactScroll.Events.scrollEvent.remove('begin');
            reactScroll.Events.scrollEvent.remove('end');
            window.removeEventListener('scroll', scrollHandler);
        };
    }, [setCurrent]);
    return current;
}

module.exports = useScrollSpy;
